EC_KEY_oct2key function

  1. @Native<Int Function(Pointer<ec_key_st>, Pointer<UnsignedChar>, Size, Pointer<bignum_ctx>)>(ffi.Pointer<ec_key_st>, ffi.Pointer<ffi.UnsignedChar>, ffi.Size, ffi.Pointer<bignum_ctx>)>()
int EC_KEY_oct2key(
  1. Pointer<ec_key_st> key,
  2. Pointer<UnsignedChar> buf,
  3. int len,
  4. Pointer<bignum_ctx> ctx,
)

Decodes a EC_KEY public key from a octet string \param key key to decode \param buf memory buffer with the encoded ec point \param len length of the encoded ec point \param ctx BN_CTX object (optional) \return 1 on success and 0 if an error occurred

Implementation

@ffi.Native<
  ffi.Int Function(
    ffi.Pointer<ec_key_st>,
    ffi.Pointer<ffi.UnsignedChar>,
    ffi.Size,
    ffi.Pointer<bignum_ctx>,
  )
>()
external int EC_KEY_oct2key(
  ffi.Pointer<ec_key_st> key,
  ffi.Pointer<ffi.UnsignedChar> buf,
  int len,
  ffi.Pointer<bignum_ctx> ctx,
);