EC_POINT_is_at_infinity function

  1. @Native<Int Function(Pointer<ec_group_st>, Pointer<ec_point_st>)>(ffi.Pointer<ec_group_st>, ffi.Pointer<ec_point_st>)>()
int EC_POINT_is_at_infinity(
  1. Pointer<ec_group_st> group,
  2. Pointer<ec_point_st> p
)

Checks whether the point is the neutral element of the group \param group the underlying EC_GROUP object \param p EC_POINT object \return 1 if the point is the neutral element and 0 otherwise

Implementation

@ffi.Native<
  ffi.Int Function(ffi.Pointer<ec_group_st>, ffi.Pointer<ec_point_st>)
>()
external int EC_POINT_is_at_infinity(
  ffi.Pointer<ec_group_st> group,
  ffi.Pointer<ec_point_st> p,
);