EC_POINT_oct2point function
- @Native<Int Function(Pointer<
ec_group_st> , Pointer<ec_point_st> , Pointer<UnsignedChar> , Size, Pointer<bignum_ctx> )>(ffi.Pointer<ec_group_st>, ffi.Pointer<ec_point_st>, ffi.Pointer<ffi.UnsignedChar>, ffi.Size, ffi.Pointer<bignum_ctx>)>()
- Pointer<
ec_group_st> group, - Pointer<
ec_point_st> p, - Pointer<
UnsignedChar> buf, - int len,
- Pointer<
bignum_ctx> ctx,
Decodes a EC_POINT from a octet string \param group underlying EC_GROUP object \param p EC_POINT object \param buf memory buffer with the encoded ec point \param len length of the encoded ec point \param ctx BN_CTX object (optional) \return 1 on success and 0 if an error occurred
Implementation
@ffi.Native<
ffi.Int Function(
ffi.Pointer<ec_group_st>,
ffi.Pointer<ec_point_st>,
ffi.Pointer<ffi.UnsignedChar>,
ffi.Size,
ffi.Pointer<bignum_ctx>,
)
>()
external int EC_POINT_oct2point(
ffi.Pointer<ec_group_st> group,
ffi.Pointer<ec_point_st> p,
ffi.Pointer<ffi.UnsignedChar> buf,
int len,
ffi.Pointer<bignum_ctx> ctx,
);