pthread_attr_get_qos_class_np function

  1. @Native<Int Function(Pointer<_opaque_pthread_attr_t>, Pointer<UnsignedInt>, Pointer<Int>)>(ffi.Pointer<_opaque_pthread_attr_t>, ffi.Pointer<ffi.UnsignedInt>, ffi.Pointer<ffi.Int>)>()
int pthread_attr_get_qos_class_np(
  1. Pointer<_opaque_pthread_attr_t> __attr,
  2. Pointer<UnsignedInt> __qos_class,
  3. Pointer<Int> __relative_priority
)

! @function pthread_attr_get_qos_class_np

@abstract Gets the QOS class and relative priority of a pthread attribute structure.

@param __attr The pthread attribute structure to inspect.

@param __qos_class On output, a QOS class value:

  • QOS_CLASS_USER_INTERACTIVE
  • QOS_CLASS_USER_INITIATED
  • QOS_CLASS_DEFAULT
  • QOS_CLASS_UTILITY
  • QOS_CLASS_BACKGROUND
  • QOS_CLASS_UNSPECIFIED This value may be NULL in which case no value is returned.

@param __relative_priority On output, a relative priority offset within the QOS class. This value may be NULL in which case no value is returned.

@return Zero if successful, otherwise an errno value.

Implementation

@ffi.Native<
  ffi.Int Function(
    ffi.Pointer<_opaque_pthread_attr_t>,
    ffi.Pointer<ffi.UnsignedInt>,
    ffi.Pointer<ffi.Int>,
  )
>()
external int pthread_attr_get_qos_class_np(
  ffi.Pointer<_opaque_pthread_attr_t> __attr,
  ffi.Pointer<ffi.UnsignedInt> __qos_class,
  ffi.Pointer<ffi.Int> __relative_priority,
);